Package: adjclust
Maintainer: Pierre Neuvial <pierre.neuvial@math.univ-toulouse.fr>
Authors@R: c(person("Christophe", "Ambroise", role = "aut"),
             person("Shubham", "Chaturvedi", role = "aut"),
             person("Alia", "Dehman", role = "aut"),
             person("Pierre", "Neuvial", role = c("aut", "cre"), 
                    email = "pierre.neuvial@math.univ-toulouse.fr",
		    comment = c(ORCID = "0000-0003-3584-9998")),	
             person("Guillem", "Rigaill", role = "aut"),
             person("Nathalie", "Vialaneix", role = "aut", 
                    email = "nathalie.vialaneix@inrae.fr",
		    comment = c(ORCID = "0000-0003-1156-0639")),
             person("Gabriel", "Hoffman", role = "aut"))
Date: 2024-10-07
Version: 0.6.10
License: GPL-3
Title: Adjacency-Constrained Clustering of a Block-Diagonal Similarity
        Matrix
Description: Implements a constrained version of hierarchical agglomerative 
    clustering, in which each observation is associated to a position, and only 
    adjacent clusters can be merged. Typical application fields in 
    bioinformatics include Genome-Wide Association Studies or Hi-C data 
    analysis, where the similarity between items is a decreasing function of 
    their genomic distance. Taking advantage of this feature, the implemented 
    algorithm is time and memory efficient. This algorithm is described in 
    Ambroise et al (2019) <doi:10.1186/s13015-019-0157-4>.
Depends: R (>= 4.0.0)
Imports: stats, graphics, grDevices, Rcpp (>= 1.0.6), Matrix,
        sparseMatrixStats, methods, utils, capushe, ggplot2,
        dendextend, rlang
Suggests: knitr, testthat, rmarkdown, rioja, HiTC, snpStats,
        BiocGenerics
biocViews: Clustering, FeatureExtraction
VignetteBuilder: knitr
URL: https://pneuvial.github.io/adjclust/
BugReports: https://github.com/pneuvial/adjclust/issues
RoxygenNote: 7.3.2
LinkingTo: Rcpp, RcppArmadillo
Encoding: UTF-8
Language: en-US
Author: Christophe Ambroise [aut],
  Shubham Chaturvedi [aut],
  Alia Dehman [aut],
  Pierre Neuvial [aut, cre] (<https://orcid.org/0000-0003-3584-9998>),
  Guillem Rigaill [aut],
  Nathalie Vialaneix [aut] (<https://orcid.org/0000-0003-1156-0639>),
  Gabriel Hoffman [aut]
Built: R 4.4.2; x86_64-apple-darwin23.6.0; 2024-11-10 11:57:00 UTC; unix
