# Generated by roxygen2: do not edit by hand

S3method(adjClust,dgCMatrix)
S3method(adjClust,dgTMatrix)
S3method(adjClust,dgeMatrix)
S3method(adjClust,dist)
S3method(adjClust,dsCMatrix)
S3method(adjClust,dsTMatrix)
S3method(adjClust,dsyMatrix)
S3method(adjClust,matrix)
S3method(as.hclust,chac)
S3method(correct,chac)
S3method(diagnose,chac)
S3method(head,chac)
S3method(hicClust,HTCexp)
S3method(hicClust,Matrix)
S3method(hicClust,character)
S3method(hicClust,data.frame)
S3method(hicClust,dgCMatrix)
S3method(hicClust,dgeMatrix)
S3method(hicClust,dsCMatrix)
S3method(hicClust,matrix)
S3method(plot,chac)
S3method(plotSim,HTCexp)
S3method(plotSim,SnpMatrix)
S3method(plotSim,default)
S3method(plotSim,dgCMatrix)
S3method(plotSim,dist)
S3method(plotSim,dsCMatrix)
S3method(print,chac)
S3method(select,chac)
S3method(snpClust,dgCMatrix)
S3method(snpClust,dsCMatrix)
S3method(snpClust,matrix)
S3method(snpClust,snpStats)
S3method(summary,chac)
export(adjClust)
export(correct)
export(cutree_chac)
export(diagnose)
export(hicClust)
export(plotSim)
export(select)
export(snpClust)
import(Rcpp)
import(ggplot2)
importFrom(Matrix,diag)
importFrom(Matrix,forceSymmetric)
importFrom(Matrix,isSymmetric)
importFrom(Matrix,t)
importFrom(capushe,DDSE)
importFrom(capushe,Djump)
importFrom(dendextend,"%>%")
importFrom(dendextend,as.ggdend)
importFrom(dendextend,set)
importFrom(grDevices,dev.flush)
importFrom(grDevices,dev.hold)
importFrom(graphics,axis)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(rlang,.data)
importFrom(sparseMatrixStats,colCumsums)
importFrom(sparseMatrixStats,rowCumsums)
importFrom(stats,as.dendrogram)
importFrom(stats,as.hclust)
importFrom(stats,cutree)
importFrom(stats,is.leaf)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,str)
useDynLib(adjclust, .registration = TRUE)
